

---------------- Table 4.1 in Ford's book  (surfaceWater as a function of volume of water in the lake)

waterObsL     = {0,    1000,  2000, 3000, 4000, 5000, 6000, 7000, 8000}   -- KAF
surfaceObsL   = {0,    24.7,  35.3, 48.6, 54.3, 57.2, 61.6, 66.0, 69.9}   -- KA
elevationObsL = { 6224, 6335, 6369, 6392, 6412, 6430, 6447, 6463, 6477}   -- feet

function estimateSurfaceArea (water)

	a = 8.1414177963836043E-01
	b = 2.5222522481624796E-02
	c = -3.8848123899271551E-06
	d = 2.2744107985861461E-10

	local surfaceArea = a + b*water + c*water^2 + d*water^3 

	return surfaceArea  -- in KA

end
---------- Table 4.1 in Ford's book  (elevation as a function of volume of water in the lake)
function estimateElevation (water)

	a = 6.2344545468507940E+03
	b = 9.6353533955755757E-02
	c = -1.6848484772520475E-05
	d = 1.0858585974826696E-09

	local elevation = a + b*water + c*water^2 + d*water^3 

	return elevation -- in feet
end
-- Table 4.2 - in Ford's book relates specific gravity to evaporation rate reduction
-----------
specificGravity          = {1.00,  1.05, 1.10, 1.15, 1.20, 1.25, 1.30, 1.35, 1.40}   
evaporationRateFactor    = {1.000, 0.963, 0.926, 0.880, 0.883, 0.785, 0.737, 0.688, 0.640}  

function evapRateFactor (specificGravity)

 	a = -1.4208080808073591E+00;
 	b = 6.6409259259240558E+00;
 	c = -5.5515151515135548E+00;
 	d = 1.3265993265988749E+00;

 	local evapRateReductionFactor = a + b*specificGravity+ c*specificGravity^2 + d*specificGravity^3 

	return evapRateReductionFactor  -- dimension-less
end
---------

function calcEvaporation (model)
    -- mass fresh water -- in millions of tons
	local massFreshwater = model.stocks.waterVolume * model.params.massFreshWaterPerKAF
    -- specific gravity -- dimension-less
	local specificGravity = (massFreshwater + model.params.dissolvedSolids) / massFreshwater
    -- evaporation rate (in feet/year)
	local evapRate = evapRateFactor (specificGravity) * model.params.freshWaterEvaporationRate
    -- evaporation (in KAF/year)
	local evapVolume   = model.variables.surfaceArea * evapRate

	return evapVolume
end

function changes (model)
    -- calculate the surface area 
    model.variables.surfaceArea   = estimateSurfaceArea (model.stocks.waterVolume)
    -- estimate current elevation
    model.outcomes.elevation      = estimateElevation   (model.stocks.waterVolume) 
    -- calculate the input from precipitation
    model.flows.precipitation     = model.variables.surfaceArea * model.params.precipitationRate
    -- calculate the evaporation volume
    model.flows.evaporation       = calcEvaporation (model)

    local otherOut =      model.flows.evaporationGrantLake  
                        + model.flows.evapotranspirationVeg
                        + model.flows.groundwaterExport
                        + model.flows.exposedLakeBottomEvap

    local otherIn  =      model.flows.otherSierraRunoff
                        + model.flows.nonSierraRunoff
                        + model.flows.netSurfacePrecip
                        + model.flows.diversionInflows

    model.stocks.waterVolume = model.stocks.waterVolume
                             + model.flows.precipitation
                             + model.flows.sierraRunoff    -- water from the mountains
                             + otherIn
                             - model.flows.evaporation
                             - otherOut
                             - model.policy.waterExport

    if (model.stocks.waterVolume <= 0 ) then
            model.stocks.waterVolume = 0
    end
end

-- for reference, 1 KAF = 1233481.8 m^3 = 1.2 million m^3

__monoLakeModel = {
    policy    =  { waterExport   = 0     },              -- kilo-acre*feet/year
	outcomes  =  { elevation     = 6378  },              -- feet
	stocks    =  { waterVolume   = 2228  },              -- KAF
	variables =  { surfaceArea   = 0     },              -- kilo-acres
	flows     =  { 
                    -- main natural inflow
                    sierraRunoff              = 150.0,   -- KAF/year
					-- main natural outflows 
					evaporation               =   0,     -- KAF/year
					precipitation             =   0,     -- KAF/year
					-- other outflows
					evaporationGrantLake      =   1.3,   -- KAF/year
					evapotranspirationVeg     =  13.0,   -- KAF/year
					exposedLakeBottomEvap     =  12.0,   -- KAF/year
					groundwaterExport         =   7.3,   -- KAF/year
					-- other inflows
					otherSierraRunoff         =  17.0,   -- KAF/year
					nonSierraRunoff           =  20.0,   -- KAF/year
					netSurfacePrecip          =   9.0,   -- KAF/year
					diversionInflows          =   1.6    -- KAF/year
				},
	params  =   { 
                    precipitationRate         =   0.667,  -- feet/year
                    freshWaterEvaporationRate =   3.75,   -- feet/year
                    massFreshWaterPerKAF      =   1.359,  -- million tons/KAF
                    dissolvedSolids           = 230.0     -- million tons
	            }
}

